document.addEventListener('DOMContentLoaded', function() {
  const ratesContainer = document.getElementById('rates-container');
  const addRateButton = document.getElementById('add-rate');
  const calculateButton = document.getElementById('calculate');
  const resultsSection = document.getElementById('results');
  const resultsGrid = document.getElementById('results-grid');

  // Add initial rate input
  addRateInput();

  addRateButton.addEventListener('click', addRateInput);

  calculateButton.addEventListener('click', function() {
    const amount = parseFloat(document.getElementById('amount').value);
    const duration = parseInt(document.getElementById('duration').value);
    const rates = Array.from(document.querySelectorAll('.rate')).map(input => parseFloat(input.value));

    if (!validateInputs(amount, duration, rates)) return;

    resultsGrid.innerHTML = '';
    rates.forEach(rate => {
      const result = calculateLoan(amount, duration, rate);
      resultsGrid.appendChild(createResultCard(rate, result));
    });

    resultsSection.classList.remove('hidden');
  });

  function addRateInput() {
    const rateInput = document.createElement('div');
    rateInput.className = 'rate-input';
    rateInput.innerHTML = `
      <label>Taux d'intérêt (%):</label>
      <input type="number" class="rate" min="0" step="0.01" required>
      <button class="remove-rate">×</button>
    `;
    ratesContainer.appendChild(rateInput);

    rateInput.querySelector('.remove-rate').addEventListener('click', function() {
      if (ratesContainer.children.length > 1) {
        ratesContainer.removeChild(rateInput);
      }
    });
  }

  function validateInputs(amount, duration, rates) {
    if (isNaN(amount) || amount <= 0) {
      alert('Veuillez entrer un montant de prêt valide.');
      return false;
    }
    if (isNaN(duration) || duration <= 0) {
      alert('Veuillez entrer une durée valide.');
      return false;
    }
    if (rates.some(rate => isNaN(rate) || rate < 0)) {
      alert('Veuillez entrer des taux d\'intérêt valides.');
      return false;
    }
    return true;
  }

  function calculateLoan(amount, duration, rate) {
    const monthlyRate = rate / 100 / 12;
    const numberOfPayments = duration * 12;
    const monthlyPayment = amount * monthlyRate / (1 - Math.pow(1 + monthlyRate, -numberOfPayments));
    const totalCost = monthlyPayment * numberOfPayments;
    const totalInterest = totalCost - amount;

    return {
      monthlyPayment: monthlyPayment.toFixed(2),
      totalCost: totalCost.toFixed(2),
      totalInterest: totalInterest.toFixed(2)
    };
  }

  function createResultCard(rate, result) {
    const card = document.createElement('div');
    card.className = 'result-card';
    card.innerHTML = `
      <h3>Taux: ${rate.toFixed(2)}%</h3>
      <p>Mensualité: ${result.monthlyPayment} €</p>
      <p>Coût total: ${result.totalCost} €</p>
      <p>Intérêts totaux: ${result.totalInterest} €</p>
    `;
    return card;
  }
});